@@ -1,4 +1,4 @@
-
+# -*- coding: iso-8859-1 -*-
 # This file contains the lists of error messages used by xmlproc
 
 import string
@@ -8,6 +8,8 @@ import string
 # Todo:
 # - 3047 needed in Swedish, Norwegian and French
 # - 2024 ditto
+# - 2025 ditto
+# - 2004 must be retranslated
 
 error_lists={}  # The hash of errors
 
@@ -44,7 +46,7 @@ english={
     2001: "Element '%s' not allowed here",
     2002: "Document root element '%s' does not match declared root element",
     2003: "Element '%s' not declared",
-    2004: "Element '%s' ended, but not finished",
+    2004: "Element '%s' ended before required elements found (%s)",
     2005: "Character data not allowed in the content of this element",
     2006: "Attribute '%s' not declared",
     2007: "ID '%s' appears more than once in document",
@@ -65,6 +67,7 @@ english={
     2022: "Notation attribute '%s' uses undeclared notation '%s'",
     2023: "Unparsed entity '%s' uses undeclared notation '%s'",
     2024: "Cannot resolve relative URI '%s' when document URI unknown",
+    2025: "Element '%s' missing before element '%s'",
 
     # --- Well-formedness errors: 3000-3999
     # From xmlutils
@@ -87,7 +90,7 @@ english={
     3012: "Standalone declaration on text declaration not allowed",
     3045: "Processing instruction target names beginning with 'xml' are reserved",
     3046: "Unsupported XML version",
-    
+
     # From xmlproc.XMLProcessor
     3013: "Illegal construct",
     3014: "Premature document end, element '%s' not closed",
@@ -123,7 +126,7 @@ english={
     3043: "Conditional section not closed",
     3044: "Token '%s' defined more than once",
     # next: 3049
-    
+
     # From regular expressions that were not matched
     3900: "Not a valid name",
     3901: "Not a valid version number (%s)",
@@ -136,7 +139,7 @@ english={
     3909: "Not a valid attribute default definition",
     3910: "Not a valid enumerated attribute value",
     3911: "Not a valid standalone declaration",
-    
+
     # --- Internal errors: 4000-4999
     4000: "Internal error: Entity stack broken",
     4001: "Internal error: Entity reference expected.",
@@ -146,7 +149,7 @@ english={
     # --- XCatalog errors: 5000-5099
     5000: "Uknown XCatalog element: %s.",
     5001: "Required XCatalog attribute %s on %s missing.",
-     
+
     # --- SOCatalog errors: 5100-5199
     5100: "Invalid or unsupported construct: %s.",
     }
@@ -169,7 +172,7 @@ norsk.update({
     1901: "Navnerommets URI kan ikke vre tomt",
     1902: "Navnerommets prefiks er ikke deklarert",
     1903: "Attributt-navn ikke unike etter navneroms-prosessering",
-    
+
     # --- Validity errors: 2000-2999
     2000: "Faktisk verdi til attributtet '%s' er ikke lik #FIXED-verdien",
     2001: "Elementet '%s' er ikke tillatt her",
@@ -250,7 +253,7 @@ norsk.update({
     3041: "'Conditional sections' er ikke tillatt i det interne DTD-subsettet",
     3043: "'Conditional section' ikke lukket",
     3044: "Symbolet '%s' er definert mer enn en gang",
-    
+
     # From regular expressions that were not matched
     3900: "Ikke et gyldig navn",
     3901: "Ikke et gyldig versjonsnummer (%s)",
@@ -263,7 +266,7 @@ norsk.update({
     3909: "Ikke en gyldig attributt-standard-verdi",
     3910: "Ikke en gyldig verdi for opprams-attributter",
     3911: "Ikke en gyldig verdi for 'standalone'",
-    
+
     # --- Internal errors: 4000-4999
     4000: "Intern feil: Entitets-stakken korrupt.",
     4001: "Intern feil: Entitets-referanse forventet.",
@@ -272,7 +275,7 @@ norsk.update({
     # --- XCatalog errors: 5000-5099
     5000: "Ukjent XCatalog-element: %s.",
     5001: "Pkrevd XCatalog-attributt %s p %s mangler.",
-     
+
     # --- SOCatalog errors: 5100-5199
     5100: "Ugyldig eller ikke stttet konstruksjon: %s.",
     })
@@ -297,7 +300,7 @@ svenska.update({
     1901: "Namnrymdens URI fr inte vara tom (mste deklareras)",
     1902: "Namnrymdsprefixet r inte deklarerat",
     1903: "Attribut-namn inte unika efter namnrymds-prosessering",
-    
+
     # --- Validity errors: 2000-2999
     2000: "Attributet '%s' faktiska vrde r inte likt #FIXED-vrdet",
     2001: "Elementet '%s' tillts inte hr",
@@ -391,7 +394,7 @@ svenska.update({
     3909: "Inge giltigt attributstandardvrde",
     3910: "Ikke en gyldig attributt-standard-verdi",
     3911: "Ikke en gyldig verdi for 'standalone'",
-    
+
     # --- Internal errors: 4000-4999
     4000: "Internt fel: Entitetsstacken korrupt.",
     4001: "Internt fel: Entitetsreferans frvntad.",
@@ -400,7 +403,7 @@ svenska.update({
     # --- XCatalog errors: 5000-5099
     5000: "Oknt XCatalog-element: %s.",
     5001: "Ndvndigt XCatalog-attribut %s p %s saknas.",
-     
+
     # --- SOCatalog errors: 5100-5199
     5100: "Konstruktionen: %s r ogiltig eller saknar std.",
     })
@@ -474,7 +477,7 @@ french.update({
     3012: "Une dclaration indpendante de texte sont interdites",
     3045: "Les noms de cibles d'instruction de traitement commenant par 'xml' sont rservs",
     3046: "Version de XML non supporte",
-    
+
     # From xmlproc.XMLProcessor
     3013: "Construction illgale",
     3014: "Fin de document prmature, l'lment '%s' n'est pas ferm",
@@ -510,7 +513,7 @@ french.update({
     3043: "La section conditionnelle n'est pas ferme",
     3044: "Le marqueur '%s' est dfini plusieurs fois",
     # next: 3047
-    
+
     # From regular expressions that were not matched
     3900: "Nom invalide",
     3901: "Numro de version invalide (%s)",
@@ -523,7 +526,7 @@ french.update({
     3909: "Dfinitionde valeur par dfaut d'attribut invalide",
     3910: "Valeur d'attribut numr invalide",
     3911: "Dclaration autonome invalide",
-    
+
     # --- Internal errors: 4000-4999
     4000: "Erreur interne : pile dentits casse",
     4001: "Erreur interne : rfrence  une entit attendue.",
@@ -533,17 +536,151 @@ french.update({
     # --- XCatalog errors: 5000-5099
     5000: "L'lment de XCatalog est inconnu : %s.",
     5001: "L'attribut de XCatalog  %s requis sur %s est manquant.",
-     
+
     # --- SOCatalog errors: 5100-5199
     5100: "Construction invalide ou non supporte : %s.",
     })
 
+# Errors in Spanish
+# Contributed by Ricardo Javier Cardenes (ricardo@conysis.com)
+
+spanish = {
+
+    # --- Warnings: 1000-1999
+    1000: "Prefijo de espacio de nombres sin declarar '%s'",
+    1002: "Codificacin no soportada '%s'",
+    1003: "Sintaxis de espacio de nombres obsoleta",
+    1005: "Caracter nmero '%d' no soportado en la referencia a caracter",
+    1006: "El elemento '%s' tiene lista de atributos, pero no declaracin de elemento",
+    1007: "El atributo '%s' est definido ms de una vez",
+    1008: "Modelo de contenido ambiguo",
+
+    # --- Namespace warnings
+    1900: "Los prefijos de espacio de nombres no pueden contener ':'.",
+    1901: "Las URI de los espacios de nombre no pueden estar vacas",
+    1902: "Prefijo de espacio de nombres sin declarar",
+    1903: "Nombres de atributo repetidos despus de procesar el espacio de nombres",
+
+    # --- Validity errors: 2000-2999
+    2000: "El valor real del atributo '%s' no se corresponde al valor fijado",
+    2001: "No se permite aqu el elemento '%s'",
+    2002: "El elemento '%s' raz del documento no es el mismo que se declar",
+    2003: "El elemento '%s' no est declarado",
+    2004: "El elemento '%s' termina antes de encontrar los elementos requeridos (%s)",
+    2005: "No se permite texto en el contenido de este elemento",
+    2006: "El atributo '%s' no ha sido declarado",
+    2007: "El ID '%s' aparece ms de una vez en el documento",
+    2008: "Slo se permiten entidades sin analizar como valores de los atributos ENTITY",
+    2009: "No est declarada la notacin '%s'",
+    2010: "No est presente el atributo '%s' necesario",
+    2011: "IDREF referida a un ID '%s', que no existe",
+    2012: "El elemento '%s' est declarado ms de una vez",
+    2013: "Slo se permite un atributo ID por cada tipo de elemento",
+    2014: "Los atributos ID no pueden ser #FIXED ni tener valor por defecto",
+    2015: "xml:space debe ser declarado como tipo enumerado",
+    2016: "xml:space debe tener exactamente los valores 'default' y 'preserve'",
+    2017: "'%s' no es un tipo vlido para el atributo '%s'",
+    2018: "El valor del atributo '%s' debe ser un nombre vlido",
+    2019: "El valor del atributo '%s' no es un NMTOKEN vlido",
+    2020: "El valor del atributo '%s' no es un NMTOKENS vlido",
+    2021: "El smbolo '%s' en el valor del atributo '%s' no es un nombre vlido",
+    2022: "El atributo de notacin '%s' usa la notacin '%s', que no est declarada",
+    2023: "La entidad sin analizar '%s' usa la notacin '%s', que no est declarada",
+    2024: "No se puede resolver la URI relativa '%s' si se desconoce la URI del documento",
+    2025: "No se encuentra el elemento '%s' antes del '%s'",
+
+    # --- Well-formedness errors: 3000-3999
+    # From xmlutils
+    3000: "No pude abrir el recurso '%s'",
+    3001: "Se empez la construccin, pero no se pudo completar",
+    3002: "Aqu se esperaba un espacio en blanco",
+    3003: "'%s' no se corresponde",   ## FIXME: This must be redone
+    3004: "Se esperaba %s o '%s'",
+    3005: "Se esperaba '%s'",
+    3047: "La codificacin '%s' es conflictiva con la autodetectada",
+    3048: "Problema de conversin de conjunto de caracteres: %s",
+
+    # From xmlproc.XMLCommonParser
+    3006: "Se esperaba SYSTEM o PUBLIC",
+    3007: "La declaracin de texto debe aparecer la primera en la entidad",
+    3008: "La declaracin XML debe aparecer la primera en el documento",
+    3009: "Varias declaraciones de texto en la misma entidad",
+    3010: "Mltiples declaraciones XML en el mismo documento",
+    3011: "Falta la versin en la declaracin XML",
+    3012: "No se permite una declaracin 'standalone' en una declaracin de texto",
+    3045: "Los nombres de PI que comienzan por 'xml' estn reservados",
+    3046: "Versin XML no soportada",
+    
+    # From xmlproc.XMLProcessor
+    3013: "Construccin ilegal",
+    3014: "El documento acab prematuramente. No se cerr el elemento '%s'",
+    3015: "Fin prematuro del documento. No hay elemento raz",
+    3016: "El atributo '%s' est duplicado",
+    3017: "No se permiten elementos fuera del raz",
+    3018: "Caracter ilegal nmero '%d' en la referencia a caracter",
+    3019: "Detectada recursividad de entidades",
+    3020: "No se permiten referencias a entidades externas en los valores de los atributos",
+    3021: "Entidad '%s' sin declarar",
+    3022: "No se permite '<' en los valores de atributos",
+    3023: "Se encontr la etiqueta de fin de '%s', pero se esperaba '%s'",
+    3024: "Element '%s' not open",
+    3025: "No debe aparecer ']]>' dentro de datos de texto",
+    3027: "No es un nmero de caracter vlido",
+    3028: "No se permite la referencia a caracteres fuera del elemento raz",
+    3029: "No se admite texto fuera del elemento raz",
+    3030: "No se admiten referencias a entidades fuera del elemento raz",
+    3031: "No se admiten referencias a entidades sin analizar en el contenido de un elemento",
+    3032: "Mltiples declaraciones de tipo de documento",
+    3033: "No se admite una declaracin de tipo de documento dentro del elemento raz",
+    3034: "Fin prematuro de un subconjunto interno de DTD",
+    3042: "Un elemento cruza los lmites de la entidad",
+
+    # From xmlproc.DTDParser
+    3035: "Las entidades paramtricas no pueden ser de tipo 'unparsed'",
+    3036: "No se permiten referencias a entidades paramtricas en un subconjunto interno de declaraciones",
+    3037: "No se permiten referencias a entidades externas en texto de reemplazo de entidades",
+    3038: "Entidad paramtrica desconocida '%s'",
+    3039: "Se esperaba un tipo o una lista de alternativas",
+    3040: "No se puede mezclar listas secuenciales con alternativas",
+    3041: "No se admiten secciones condicionales en subconjuntos internos",
+    3043: "Seccin condicional sin cerrar",
+    3044: "Se defini el smbolo '%s' ms de una vez",
+    # next: 3049
+    
+    # From regular expressions that were not matched
+    3900: "No es un nombre vlido",
+    3901: "No es un nmero de versin vlido (%s)",
+    3902: "No es un nombre de codificacin vlido",
+    3903: "No es un comentario vlido",
+    3905: "No es un nmero hexadecimal vlido",
+    3906: "No es un nmero vlido",
+    3907: "No es una referencia a parmetro vlida",
+    3908: "No es un tipo de atributo vlido",
+    3909: "No es una definicin de atributo por defecto vlida",
+    3910: "No es un valor de atributo enumerado vlido",
+    3911: "No es una declaracin 'standalone' vlida",
+    
+    # --- Internal errors: 4000-4999
+    4000: "Error interno: Pila de la entidad corrupta",
+    4001: "Error interno: Se esperaba una referencia a entidad.",
+    4002: "Error interno: Nmero de error desconocido.",
+    4003: "Error interno: No se admiten refrencias PE externas en las declaraciones",
+
+    # --- XCatalog errors: 5000-5099
+    5000: "Elemento XCatalog desconocido: %s.",
+    5001: "Falta el atributo XCatalog %s necesario en %s.",
+     
+    # --- SOCatalog errors: 5100-5199
+    5100: "Construccin invlida o no soportada: %s.",
+    }
+
 # Updating the error hash
 
 add_error_list("en", english)
 add_error_list("no", norsk)
 add_error_list("sv", svenska)
 add_error_list("fr", french)
+add_error_list("es", spanish)
 
 # Checking
 
@@ -561,11 +698,13 @@ def _test():
     no = norsk.keys()
     sv = svenska.keys()
     fr = french.keys()
+    es = spanish.keys()
 
     en.sort()
     no.sort()
     sv.sort()
     fr.sort()
+    es.sort()
 
     print "en == no"
     compare(en, no)
@@ -575,6 +714,9 @@ def _test():
 
     print "en == fr"
     compare(en, fr)
-    
+
+    print "en == es"
+    compare(en, es)
+
 if __name__ == "__main__":
     _test()
