@@ -40,7 +40,7 @@ elements which have no content.  This is needed to properly support
 XML and XHTML.
 
 """
-__version__ = '$Revision: 1.6 $'
+__version__ = '$Revision: 1.9 $'
 
 import string
 
@@ -61,6 +61,7 @@ class Syntax:
     dsc = "]"                           # declaration subset close
     ero = "&"                           # entity reference open
     lit = '"'                           # literal start or end
+    lit_quoted = '&quot;'               # quoted literal
     lita = "'"                          # literal start or end (alternative)
     mdo = "<!"                          # markup declaration open
     mdc = ">"                           # markup declaration close
@@ -268,6 +269,7 @@ class XmlWriter:
         stag = "%s%s%s" % (prefix, self.__syntax.stago, tag)
         prefix = "%s %s" % (prefix, (len(tag) * " "))
         lit = self.__syntax.lit
+        lita = self.__syntax.lita
         vi = self.__syntax.vi
         a = ''
         if self._flowing != self.__stack[-1][0]:
@@ -285,7 +287,15 @@ class XmlWriter:
         for k, v in attrs.items():
             if v is None:
                 continue
-            a = ' %s%s%s%s%s' % (k, vi, lit, escape(str(v)), lit)
+            v = str(v)
+            if string.find(v, lit) == -1:
+                a = ' %s%s%s%s%s' % (k, vi, lit, escape(str(v)), lit)
+            elif string.find(v, lita) == -1:
+                a = ' %s%s%s%s%s' % (k, vi, lita, escape(str(v)), lita)
+            else:
+                a = ' %s%s%s%s%s' % (k, vi, lit,
+                                     escape(str(v), {lit:self.__syntax.lit_quoted}),
+                                     lita)
             if (self._offset + len(a)) > self.lineLength:
                 self._write(line + "\n")
                 line = prefix + a
@@ -363,11 +373,12 @@ class XmlWriter:
         pass
 
     def processingInstruction(self, target, data):
+        self._check_pending_content()
         s = "%s%s %s%s" % (self.__syntax.pio, target, data, self.__syntax.pic)
         prefix = self._prefix[:-self.indentation] \
                  + (" " * self.indentEndTags)
         if "\n" in s:
-            pos = string.rfind(s, "\n")
+            p = string.rfind(s, "\n")
             if self._flowing and not self._packing:
                 self._write(prefix + s + "\n")
                 self._offset = 0
@@ -379,7 +390,7 @@ class XmlWriter:
             self._offset = 0
         else:
             self._write(s)
-            self._offset = len(s) - (p + 1)
+            self._offset = self._offset + len(s)
 
 
     # This doesn't actually have a SAX equivalent, so we'll use it as
@@ -423,7 +434,7 @@ class XmlWriter:
                 rpos = string.rfind(s, "\n")
                 self._offset = len(s) - (rpos + 1) + len(end)
             else:
-                self._offset = self.__offset + len(s) + len(start + end)
+                self._offset = self._offset + len(s) + len(start + end)
             self._write(s)
         else:
             self._offset = 0
